@@ -1,13 +1,10 @@
-require 'rubygems'
-
-gem 'bcrypt-ruby', '~>2.0.3'
 require 'bcrypt'
 
 module DataMapper
   module Types
     class BCryptHash < DataMapper::Type
       primitive String
-      size 60
+      length    60
 
       def self.load(value, property)
         typecast(value, property)
