@@ -4,9 +4,10 @@ module DataMapper
   module Types
     class FilePath < DataMapper::Type
       primitive String
+      length    255
 
       def self.load(value, property)
-        if value.nil?
+        if value.blank?
           nil
         else
           Pathname.new(value)
@@ -14,7 +15,7 @@ module DataMapper
       end
 
       def self.dump(value, property)
-        return nil if value.nil?
+        return nil if value.blank?
         value.to_s
       end
 
@@ -23,5 +24,5 @@ module DataMapper
         value.kind_of?(Pathname) ? value : load(value, property)
       end
     end # class FilePath
-  end # module Types
-end # module DataMapper
+  end # module Types
+end # module DataMapper
